#superset-fullscreen-exit {
    visibility: hidden;
    z-index: 1;
    position: fixed;
    top: 10px;
    right: 10px;
}

.fullScreen {
    width: 100%;
    height: 100%;
    z-index: 0;
    position: absolute;
    top: 0;
    left: 0;
}

iframe {
    width:100%;
    min-height:600px;
}

#graph {
    width: 80vw;
    position: relative;
    left: calc(-30vw + 35%);
}